import { getToken, setToken, removeToken } from '@/utils/auth'
import API from '@/api'

const ModuleUser = {
 state : {
    token: getToken(),
    name: '',
    userInfo: '',
  },
  getters: {
    token: state => state.token,
    name: state => state.name,
    userInfo: state => state.userInfo
  },
 mutations : {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_USERINFO: (state, userInfo) => {
      state.userInfo = userInfo
    },
  },
  
 actions : {
    // gisuser login
    login({ commit }, userInfo) {
      const { account, password,nonceId,verificationCode} = userInfo
      return new Promise((resolve, reject) => {
        API.account.login({
          account,
          password,
          nonceId,
          verificationCode
        }).then(response => {
          const { data } = response
          commit('SET_TOKEN', data.token)
          setToken(data.token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },
  
    // get user info
    userInfo({ commit }) {
      return new Promise((resolve) => {
        API.account.userInfo().then(response => {
          const { data } = response
          const { name } = data
          commit('SET_NAME', name)
          commit('SET_USERINFO', data)
          resolve(data)
        })
      })
    },
  
    // user logout
    logout({ commit, state, dispatch }) {
      return new Promise((resolve, reject) => {
        // API.account.logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_NAME', '')
          commit('SET_USERINFO', '')
          removeToken()
          // reset visited views and cached views
          // to fixed https://github.com/PanJiaChen/vue-element-admin/issues/2485
          resolve()
        // }).catch(error => {
        //   reject(error)
        // })
      })
    },
    // remove token
    resetToken({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    },
  },
}
export default ModuleUser;