import axios from 'axios'
import store from '@/store'
import { getToken } from '@/utils/auth'
import { ElNotification } from 'element-plus';
import router from '../router';
let loadingInstance = null


const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
  // baseURL: apiUrl, // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 1000 * 60 * 60 * 5 // request timeout
})

// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent

    if (getToken()) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers['token'] = getToken()
    }
    // 时间
    if (config.params) {
      config.params.nowDate = new Date()
    }
    if (config.loadingInstance === true) {
      loadingInstance = Loading.service({
        text: '正在导入请等待...'
      })
    }
    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response.data
    // console.log(res)

    if (loadingInstance) {
      loadingInstance.close()
    }

    // if the custom code is not 20000, it is judged as an error.
    else if (res.code && res.code !== 200) {

      if (res.code === 1) {
        ElNotification({
          title: '错误',
          message: res.msg,
          type: 'error',
        })
      }
      else if (res.code === 10010 && res.msg === '图形验证码过期，请点击刷新。') {
        ElNotification({
          title: '提示',
          message: res.msg,
          type: 'info',
        })
      }
      else if (res.code === 10010 && res.msg === '验证码错误，请重新输入') {
        ElNotification({
          title: '提示',
          message: res.msg,
          type: 'info',
        })
      }
      else if (res.code === 10005 || res.code === 10004 || res.code === 401) { // 10005非法token, 10004用户未登录
        ElNotification({
          title: '提示',
          message: '登录过期，请重新登录。',
          type: 'info',
        })
        store.dispatch('resetToken').then(() => {
          router.push({ name: 'Login' })
        })
      } else {
        ElNotification({
          title: '提示',
          message: res.msg,
          type: 'info',
        })
      }
      return Promise.reject(new Error(res.msg || 'Error'))
    } else if (response.config.originResponse) {
      return response
    } else {
      return res
    }
  },
  error => {
    console.log('err' + error)
    return Promise.reject(error)
  }
)

export default service
